fire_generator Package
======================

:mod:`fire_generator` Package
-----------------------------

.. automodule:: landlab.components.fire_generator
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`generate_fire` Module
---------------------------

.. automodule:: landlab.components.fire_generator.generate_fire
    :members:
    :undoc-members:
    :show-inheritance:

